@@ -5,6 +5,11 @@ from tornado.concurrent import return_future
 
 from motorengine import ASCENDING
 from motorengine.connection import get_connection
+from motorengine.fields.embedded_document_field import EmbeddedDocumentField
+from motorengine.query.lesser_than import LesserThanQueryOperator
+from motorengine.query.greater_than import GreaterThanQueryOperator
+from motorengine.query.lesser_than_or_equal import LesserThanOrEqualQueryOperator
+from motorengine.query.greater_than_or_equal import GreaterThanOrEqualQueryOperator
 
 
 class QuerySet(object):
@@ -14,6 +19,13 @@ class QuerySet(object):
         self._limit = 300
         self._order_fields = []
 
+        self.available_query_operators = {
+            'lt': LesserThanQueryOperator,
+            'gt': GreaterThanQueryOperator,
+            'lte': LesserThanOrEqualQueryOperator,
+            'gte': GreaterThanOrEqualQueryOperator
+        }
+
     @property
     def is_lazy(self):
         return self.__klass__.__lazy__
@@ -146,7 +158,8 @@ class QuerySet(object):
                 self.coll(alias).remove(instance._id, callback=self.handle_remove(callback))
         else:
             if self._filters:
-                self.coll(alias).remove(self._filters, callback=self.handle_remove(callback))
+                remove_filters = self.get_query_from_filters(self._filters)
+                self.coll(alias).remove(remove_filters, callback=self.handle_remove(callback))
             else:
                 self.coll(alias).remove(callback=self.handle_remove(callback))
 
@@ -191,19 +204,97 @@ class QuerySet(object):
             }
         else:
             filters = self.to_filters(**kwargs)
+            filters = self.get_query_from_filters(filters)
 
         self.coll(alias).find_one(filters, callback=self.handle_get(callback))
 
     def to_filters(self, **kwargs):
+        from motorengine import Document  # to avoid circular dependency
+
         filters = {}
         for field_name, value in kwargs.items():
-            if field_name not in self.__klass__._fields:
-                raise ValueError("Invalid filter '%s': Field not found in '%s'." % (field_name, self.__klass__.__name__))
-            field = self.__klass__._fields[field_name]
-            filters[field.db_field] = field.to_son(value)
+            original_field_name = field_name
+            field_db_name = None
+            field_value = None
+
+            operator = ""
+            if '__' in field_name:
+                filter_values = field_name.split('__')
+                operator = filter_values[-1]
+                field_name = ".".join(filter_values[:-1])
+
+            if operator and operator not in self.available_query_operators:
+                field_name = "%s.%s" % (field_name, operator)
+                operator = ""
+
+            if '.' in field_name:
+                values = field_name.split('.')
+                obj = self.__klass__
+                fields = []
+
+                for field_index, partial_field_name in enumerate(values):
+                    if not partial_field_name in obj._fields:
+                        raise ValueError("Invalid filter '%s': Field '%s' not found in '%s'." % (
+                            original_field_name,
+                            partial_field_name,
+                            obj.__name__
+                        ))
+
+                    if issubclass(obj, Document):
+                        field = obj._fields[partial_field_name]
+                    else:
+                        field = obj
+
+                    fields.append(field.db_field)
+
+                    obj = getattr(obj, partial_field_name)
+
+                    is_last = field_index == len(values) - 1
+                    if is_last:
+                        field_value = field.to_son(value)
+                        field_db_name = ".".join(fields)
+                        continue
+
+                    if not isinstance(obj, EmbeddedDocumentField):
+                        raise ValueError(
+                            ("Invalid filter '%s': Invalid operator (if this is a sub-property, then it must be "
+                                "used in embedded document fields).") % (
+                                original_field_name,
+                            )
+                        )
+
+                    obj = obj.embedded_type
+            else:
+                if field_name not in self.__klass__._fields:
+                    raise ValueError("Invalid filter '%s': Field not found in '%s'." % (field_name, self.__klass__.__name__))
+
+                if operator and operator not in self.available_query_operators:
+                    raise ValueError("Invalid filter '%s': Operator not found '%s'." % (original_field_name, operator))
+
+                field = self.__klass__._fields[field_name]
+                field_db_name = field.db_field
+                field_value = field.to_son(value)
+
+            filters[field_db_name] = {
+                "operator": operator,
+                "value": field_value
+            }
 
         return filters
 
+    def get_query_from_filters(self, filters):
+        result = {}
+
+        for filter_name, filter_desc in filters.items():
+            operator, filter_value = filter_desc['operator'], filter_desc['value']
+
+            if not operator:
+                result[filter_name] = filter_value
+            else:
+                result[filter_name] = self.available_query_operators[operator](filter_value).to_query()
+
+        return result
+
     def filter(self, **kwargs):
         '''
         Filters a queryset in order to produce a different set of document from subsequent queries.
@@ -270,7 +361,8 @@ class QuerySet(object):
         if self._order_fields:
             find_arguments['sort'] = self._order_fields
 
-        return self.coll(alias).find(self._filters, **find_arguments)
+        query_filters = self.get_query_from_filters(self._filters)
+        return self.coll(alias).find(query_filters, **find_arguments)
 
     @return_future
     def find_all(self, callback, alias=None):
